@@ -13,16 +13,16 @@ import seaborn as sns
 # from sklearn.ensemble import VotingClassifier
 # from sklearn.model_selection import GridSearchCV
 # from sklearn.preprocessing import LabelEncoder, OrdinalEncoder
-import math
+
 
 def univar_analysis(df):
     for i in df:
-        if df[i].dtype == 'object': 
-            sns.barplot(df[i].value_counts().index,df[i].value_counts())
+        if df[i].dtype == 'object':
+            sns.barplot(df[i].value_counts().index, df[i].value_counts())
             plt.title(i)
             plt.show()
         else:
-            fig, ax = plt.subplots(1,2,figsize=(10,4))
+            fig, ax = plt.subplots(1, 2, figsize=(10, 4))
             fig.tight_layout()
             ax[0].hist(df[i])
             ax[0].set_title(i)
@@ -30,36 +30,41 @@ def univar_analysis(df):
             ax[1].set_title(i)
             plt.show()
 
-def dichotomous_categorical_visual(df,target):
+
+def dichotomous_categorical_visual(df, target):
     if len(df[target].unique()) == 2:
         df_0 = df[df[target] == 0]
         df_1 = df[df[target] == 1]
         for i in df:
             if df[i].dtype == 'object':
-                fig, axes = plt.subplots(1,2,figsize=(16,6))
-                pd.crosstab(df_0[target],df_0[i]).plot(kind='bar',ax=axes[0])
-                pd.crosstab(df_1[target],df_1[i]).plot(kind='bar',ax=axes[1])
+                fig, axes = plt.subplots(1, 2, figsize=(16, 6))
+                pd.crosstab(df_0[target], df_0[i]).plot(kind='bar', ax=axes[0])
+                pd.crosstab(df_1[target], df_1[i]).plot(kind='bar', ax=axes[1])
     else:
         print("Your target variable is not dichotomous!")
 
-def categorical_visual(x,y,kind,data):
-    sns.catplot(x=x, y=y, kind=kind, data=data)
 
-def categorical_multivariate_visual(x,y,hue,kind,data):
-    sns.catplot(x=x, y=y, hue=hue, kind=kind, data=data)
+def categorical_visual(x, y, kind, data):
+    sns.catplot(x, y, hue, kind, data)
 
-def continuous_visual(df,target):
-    rows = math.ceil(len(train.select_dtypes('float').columns-1)/2)
+
+def categorical_multivariate_visual(x, y, hue, kind, data):
+    sns.catplot(x, y, hue, kind, data)
+
+
+def continuous_visual(df, target):
+    rows = np.ceil(len(train.select_dtypes('float').columns-1)/2)
     cols = 2
     # fig, axes = plt.subplots(rows,cols,figsize=(16,6))
     df_float = train.select_dtypes('float')
     for i in df_float:
-        # axes[0] = 
-        plt.subplot(rows,cols,i+1)
+        # axes[0] =
+        plt.subplot(rows, cols, i+1)
         plt.imshow(df_float[i])
         plt.show()
 
-#-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+
 
 def chi2_test():
     pass
@@ -68,7 +73,7 @@ def chi2_test():
 def pbs_test():
     num_summary = []
     for i in df_num:
-        pbs = pointbiserialr(df_num[i],df_num[target])
+        pbs = pointbiserialr(df_num[i], df_num[target])
         score_to_add = {}
         score_to_add['var'] = i
         score_to_add['pbs corr'] = pbs[0]
@@ -77,32 +82,41 @@ def pbs_test():
     df_num = pd.DataFrame(num_summary)
     df_num
 
+
 def pearson_test():
     pass
 
-def outlier_treatment(): #maybe don't need this
+
+def outlier_treatment():  # maybe don't need this
     pass
 
+
 def fill_null():
     pass
 
+
 def normalisation():
     pass
 
+
 def standardisation():
     pass
 
+
 def one_hot_encoding():
     pass
 
+
 def label_encoding():
     pass
 
+
 def ordinal_encoding():
     pass
 
+
 def pca():
     pass
 
-#addigional boosted trees models and classifiers?
-#gridsearch?
\ No newline at end of file
+# addigional boosted trees models and classifiers?
+# gridsearch?
